<?php

// Peter Bakondy <bakondyp@freemail.hu>
// Mihly Mszros <necronix@freemail.hu>

$charset = 'iso-8859-2';
$allow_recoding = TRUE;
$text_dir = 'ltr'; // ('ltr': balrl jobbra, 'rtl': jobbrl balra)
$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = 'arial, helvetica, geneva, sans-serif';
$number_thousands_separator = ' ';
$number_decimal_separator = '.';
// Byte, Kilo, Mega, Giga, Tera, Peta, Exa rvidtsei
$byteUnits = array('Bjt', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('V', 'H', 'K', 'Sze', 'Cs', 'P', 'Szo');
$month = array('Jan', 'Feb', 'Mrc', 'pr', 'Mj', 'Jn', 'Jl', 'Aug', 'Szept', 'Okt', 'Nov', 'Dec');
// Lers a $datefmt vltoz definilshoz:
// http://www.php.net/manual/en/function.strftime.php
$datefmt = '%Y. %B %d. %H:%M';

$timespanfmt = '%s nap, %s ra, %s perc, %s msodperc'; 

$strAPrimaryKey = 'Els&#337;dleges kulcsot hozzadtam: %s';
$strAbortedClients = 'Megszaktva'; 
$strAbsolutePathToDocSqlDir = 'rja be az abszolt elrsi utat a docSQL knyvtrhoz';  
$strAccessDenied = 'Hozzfrs megtagadva';
$strAccessDeniedExplanation = 'A phpMyAdmin megprblt csatlakozni a MySQL szerverhez, de a szerver elutastotta a kapcsolatot. Ellen&#337;rizze a host, username s jelsz mez&#337;ket a config.inc.php fjlban, s bizonyosodjon meg rla, hogy ezek megfelelnek a MySQL szerver adminisztrtortl kapott informciknak.';  
$strAction = 'Parancs';
$strAddAutoIncrement = 'AUTO_INCREMENT rtk hozzadsa';  
$strAddConstraints = 'Megszorts hozzadsa';  
$strAddDeleteColumn = 'Mez&#337; Oszlopokat Hozzad/Trl';
$strAddDeleteRow = 'Kritrium Sort Hozzad/Trl';
$strAddDropDatabase = 'DROP DATABASE hozzadsa';
$strAddFields = '%s mez&#337; hozzadsa';
$strAddHeaderComment = 'Egyedi megjegyzs hozzadsa a fejlchez (\\n tri a sorokat)';  
$strAddIfNotExists = 'IF NOT EXISTS hozzadsa';  
$strAddIntoComments = 'Hozzads a megjegyzshez';
$strAddNewField = 'j mez&#337; hozzadsa';
$strAddPrivilegesOnDb = 'Privilgiumok hozzadsa a kvetkez&#337; adatbzison:';
$strAddPrivilegesOnTbl = 'Privilgiumok hozzadsa a kvetkez&#337; tbln:'; 
$strAddSearchConditions = 'Keressi felttelek megadsa (az "ahol" kiktsek):';
$strAddToIndex = 'Adj az indexhez %s oszlopot';
$strAddUser = 'j felhasznl hozzadsa';
$strAddUserMessage = 'Az j felhasznlt felvettem.';
$strAddedColumnComment = 'Megjegyzs hozzf&#369;zve az oszlophoz:';  
$strAddedColumnRelation = 'Kapcsolat hozzf&#369;zve az oszlophoz:';  
$strAdministration = 'Adminisztrci'; 
$strAffectedRows = 'Keresett sorok:';
$strAfter = '%s utn';
$strAfterInsertBack = 'Vissza az el&#337;z&#337; oldalra';
$strAfterInsertNewInsert = 'j sor beszrsa';
$strAfterInsertNext = 'Kvetkez&#337; sor szerkesztse';
$strAfterInsertSame = 'Visszatrs az oldalra';  
$strAll = 'Mind';
$strAllTableSameWidth = 'minden tbla ezzel a szlessggel jelenjen meg?';
$strAlterOrderBy = 'Tbla megvltozsa rendezve e szerint:';
$strAnIndex = 'Indexet hozzadtam: %s';
$strAnalyzeTable = 'Tbla vizsglat';
$strAnd = 's';
$strAny = 'Brmely';
$strAnyHost = 'Brmely hoszt';
$strAnyUser = 'Brmely felhasznl';
$strApproximateCount = 'Becslt rtk lehet. Lsd: FAQ 3.11';
$strArabic = 'Arab';  
$strArmenian = 'rmny';  
$strAscending = 'Nvekv&#337;';
$strAtBeginningOfTable = 'A tbla elejnl';
$strAtEndOfTable = 'A tbla vgnl';
$strAttr = 'Tulajdonsgok';
$strAutodetect = 'Automatikus felismers';  
$strAutomaticLayout = 'Automatikus elrendezs';  

$strBack = 'Vissza';
$strBaltic = 'Balti';  
$strBeginCut = 'Kivgs Kezdete';
$strBeginRaw = 'Feldolgozatlan Kezdete';
$strBinLogInfo = 'Informci';
$strBinLogOriginalPosition = 'Eredeti pozci';
$strBinLogPosition = 'Pozci';
$strBinLogServerId = 'Szerver ID';
$strBinary = 'Binris';
$strBinaryDoNotEdit = 'Binris - nem szerkeszthet&#337;';
$strBookmarkAllUsers = 'Az sszes felhasznlnak engedlyezi a hozzfrst ehhez a knyvjelz&#337;hz';  
$strBookmarkDeleted = 'A knyvjelz&#337;t trltem.';
$strBookmarkLabel = 'Felirat';
$strBookmarkOptions = 'Knyvjelz&#337; opcik';  
$strBookmarkQuery = 'Feljegyzett SQL-krs';
$strBookmarkThis = 'Jegyezd fel az SQL-krst';
$strBookmarkView = 'Csak megnzhet&#337;';
$strBrowse = 'Tartalom';
$strBrowseForeignValues = 'Idegen kulcsok bngszse';  
$strBufferReadMisses = 'Olvassi hibk';
$strBulgarian = 'Bolgr';  
$strBzError = 'A phpMyAdmin nem tudta betmrteni a dump-ot, mert nem megfelel&#337; a Bz2 kiterjeszts ebben a php verziban. Er&#337;sen ajnlott a <code>$cfg[\'BZipDump\']</code> paramtert a phpMyAdmin konfigurcis fjlban <code>FALSE</code> rtkre belltani. Ha a Bz2 tmrtsi eljrst hasznlni szeretn, frisstse a php-t! Tekintse meg a %s php bug report-ot a rszletekrt.'; 
$strBzip = '"bzip-pel tmrtve"';

$strCSVOptions = 'CSV belltsok';
$strCalendar = 'Naptr';  
$strCannotLogin = 'A belps a MySQL szerverre sikertelen volt';  
$strCantLoad = 'nem tudtam betlteni a %s kiterjesztst,<br />ellen&#337;rizze a PHP konfigurcit';  
$strCantLoadRecodeIconv = 'Nem tudom betlteni az iconv vagy recode kiterjesztst a karakterkszlet-talaktshoz, lltsd be a php-t, hogy engedlyezze ezeket a kiterjesztseket vagy tiltsd le a karakterkszlet-talaktst a phpMyAdmin-ban.';
$strCantRenameIdxToPrimary = 'Nem tudom tnevezni az indexet PRIMARY-v!';
$strCantUseRecodeIconv = 'Nem tudom hasznlni az iconv, libiconv sem a recode_string funkcikat mialatt a kiterjeszts-jelentseket be kell tlteni. Ellen&#337;rizd a php konfigurcit.';
$strCardinality = 'Szmossg';
$strCarriage = 'Kocsivissza: \\r';
$strCaseInsensitive = 'bet&#369;nagysgra nem rzkeny';  
$strCaseSensitive = 'bet&#369;nagysg-rzkeny';  
$strCentralEuropean = 'Kzp-eurpai';  
$strChange = 'Vltoztat';
$strChangeCopyMode = 'j felhasznl hozzadsa ezekkel a privilgiumokkal ...';  
$strChangeCopyModeCopy = '... a rgi meg&#337;rzse.';  
$strChangeCopyModeDeleteAndReload = ' ... a rgi trlse a felhasznli tblkbl, s utna a privilgiumok jratltse.';  
$strChangeCopyModeJustDelete = ' ... a rgi trlse a felhasznli tblkbl.';  
$strChangeCopyModeRevoke = ' ... az sszes aktv privilgium visszalltsa a rgib&#337;l, s utna trlsk.';  
$strChangeCopyUser = 'Belpsi informci megvltoztatsa / Felhasznl msolsa';  
$strChangeDisplay = 'Vlassz mez&#337;t a megjelentshez';
$strChangePassword = 'Jelsz megvltoztatsa';
$strCharset = 'Karakterkszlet';  
$strCharsetOfFile = 'A fjl karakterkszlete:';
$strCharsets = 'Karakterkszlet';  
$strCharsetsAndCollations = 'Karakterkszletek s egybevetsek';  
$strCheckAll = 'sszeset kijelli';
$strCheckOverhead = 'Ellen&#337;rzs felfggesztse';  
$strCheckPrivs = 'Privilgiumok ellen&#337;rzse';  
$strCheckPrivsLong = 'Privilgiumok ellen&#337;rzse &quot;%s&quot; adatbzison.';  
$strCheckTable = 'Tbla ellen&#337;rzs';
$strChoosePage = 'Vlassz oldalt a szerkesztshez';
$strColComFeat = 'Oszlop megjegyzsek megjelentse';
$strCollation = 'Egybevets';  
$strColumnNames = 'Oszlop nevek';
$strColumnPrivileges = 'Oszlop-specifikus privilgiumok'; 
$strCommand = 'Parancs'; 
$strComments = 'Megjegyzsek';
$strCommentsForTable = 'Tbla-megjegyzsek';  
$strCompatibleHashing = 'MySQL&nbsp;4.0 kompatibilis';
$strCompleteInserts = 'Mez&#337;neveket is hozzadja';
$strCompression = 'Tmrts'; 
$strConfigFileError = 'A phpMyAdmin nem tudja olvasni a konfigurcis fjlt!<br />Lehet, hogy a php szintaktikai hibt tallt benne, vagy nem tallja a fjlt.<br />Hasznld az als linket a konfigurcis fjl helyrelltshoz, olvasd el a kapott php hibazeneteket. Tbbnyire egy idz&#337;jel vagy egy pontosvessz&#337; hinyzik valahol.<br />Ha res oldalt kapsz, minden rendben.';
$strConfigureTableCoord = 'lltsd be a(z) $s tbla koordintit';
$strConnectionError = 'Nem sikerlt a csatlakozs: rvnytelen belltsok.';  
$strConnections = 'Kapcsolat'; 
$strConstraintsForDumped = 'Kiktsek a kirt tblkhoz';  
$strConstraintsForTable = 'Kiktsek a tblhoz';  
$strCookiesRequired = 'A Cookie-kat most engedlyezned kell.';
$strCopy = 'Msols';
$strCopyTable = 'Tbla msolsa ide (adatbzis<b>.</b>tbla):';
$strCopyTableOK = '%s tblt ide msoltam: %s.';
$strCopyTableSameNames = 'Nem tudom a tblt ugyanarra msolni!';  
$strCouldNotKill = 'phpMyAdmin nem tudta megszntetni ez a szlat: %s. Meglehet, mr vget rt.'; 
$strCreate = 'Ltrehoz';
$strCreateIndex = 'Kszts egy indexet a(z) %s. oszlopon';
$strCreateIndexTopic = 'j index ltrehozsa';
$strCreateNewDatabase = 'j adatbzis ltrehozsa';
$strCreateNewTable = 'j tbla ltrehozsa a(z) %s adatbzisban';
$strCreatePage = 'j oldal ksztse';
$strCreatePdfFeat = 'PDF ksztse';
$strCreationDates = 'Dtum Kszts/Mdosts/Ellen&#337;rzs';  
$strCriteria = 'Kritrium';
$strCroatian = 'Horvt';  
$strCyrillic = 'Cirill';  
$strCzech = 'Cseh';  
$strCzechSlovak = 'Szlovk';  

$strDBComment = 'Adatbzis megjegyzs: ';
$strDBCopy = 'Adatbzis msolsa ide';
$strDBGContext = 'Tartalom';  
$strDBGContextID = 'Tartalom ID';  
$strDBGHits = 'Tallat';  
$strDBGLine = 'Vonal';  
$strDBGMaxTimeMs = 'Legnagyobb id&#337;, ms';  
$strDBGMinTimeMs = 'Legkisebb id&#337;, ms';  
$strDBGModule = 'Modul';  
$strDBGTimePerHitMs = 'Id&#337;/Tallat, ms';  
$strDBGTotalTimeMs = 'sszes id&#337;, ms';  
$strDBRename = 'Adatbzis tnevezse';  
$strDanish = 'Dn';  
$strData = 'Adat';
$strDataDict = 'Adatknyvtr';  
$strDataOnly = 'Csak adatok';
$strDatabase = 'Adatbzis';
$strDatabaseEmpty = 'Az adatbzis nz mez&#337; res!';  
$strDatabaseExportOptions = 'Adatbzis export belltsok';
$strDatabaseHasBeenDropped = '%s adatbzist eldobtam.';
$strDatabaseNoTable = 'Az adatbzis nem tartalmaz tblkat!';
$strDatabases = 'adatbzisok';
$strDatabasesDropped = '%s adatbzist sikeresen trltem.';  
$strDatabasesStats = 'Adatbzis statisztika';
$strDatabasesStatsDisable = 'Statisztika tiltsa';  
$strDatabasesStatsEnable = 'Statisztika engedlyezse';  
$strDatabasesStatsHeavyTraffic = 'Megjegyzs: az adatbzis statisztika engedlyezse nagy adatforgalomhoz vezethet a webszerver s a MySQL kztt.';  
$strDbPrivileges = 'Adatbzis-specifikus privilgiumok'; 
$strDbSpecific = 'adatbzis-specifikus';  
$strDefault = 'Alaprtelmezett';
$strDefaultValueHelp = 'Az alaprtelmezett rtkekhez rjon be egy egyszer&#369; rtket, escape karakter s idz&#337;jelek nlkl, ezt a formtumot kvetve: a';  
$strDefragment = 'Tbla tredezettsgmentestse';  
$strDelOld = 'A jelenlegi oldalon a tblahivatkozsok mr nem lnek. Akarja ezeket trlni?';  
$strDelayedInserts = 'Id&#337;ztett beszrs hasznlata';  
$strDelete = 'Trl';
$strDeleteAndFlush = 'Trlje a felhasznlt, azutn tltse be jra a privilgiumokat.'; 
$strDeleteAndFlushDescr = 'Ez a legtisztbb t, de a privilgiumok jratltse eltarthat egy ideig.'; 
$strDeleted = 'A sort trltem';
$strDeletedRows = 'Trlt sorok:';
$strDeleting = '%s trlse'; 
$strDescending = 'Cskken&#337;';
$strDescription = 'Lers';  
$strDictionary = 'sztr';  
$strDisableForeignChecks = 'Idegen kulcsok ellen&#337;rzsnek letiltsa';  
$strDisabled = 'Tiltott';
$strDisplayFeat = 'Megjelents tulajdonsgok';
$strDisplayOrder = 'Megjelents rendezs:';
$strDisplayPDF = 'PDF sma kijelzse';
$strDoAQuery = 'Csinlj egy "lekrdezst" (helyettest&#337; karakter: "%")';
$strDoYouReally = 'Biztos ez akarod? ';
$strDocu = 'Dokumentci';
$strDrop = 'Eldob';
$strDropDatabaseStrongWarning = 'Ki akarod trlni az EGSZ adatbzist?';  
$strDropSelectedDatabases = 'A kivlasztott adatbzisok trlse';  
$strDropUsersDb = 'Azon adatbzisok trlse, amelyek neve egyezik a felhasznlkkal.'; 
$strDumpSaved = 'A kirst elmetettem ebbe a fjlba: %s.';  
$strDumpXRows = '%s sor kirsa a %s. sorral kezd&#337;dik';
$strDumpingData = 'Tbla adatok:';
$strDynamic = 'dinamikus';

$strEdit = 'Szerkeszt';
$strEditPDFPages = 'PDF oldalak szerkesztse';
$strEditPrivileges = 'Privilgiumok szerkesztse';
$strEffective = 'Hatlyos';
$strEmpty = 'Kirt';
$strEmptyResultSet = 'A MySQL reset adott vissza (nincsenek sorok).';
$strEnabled = 'Engedlyezett';
$strEncloseInTransaction = 'Export lezrsa a tranzakciban';  
$strEnd = 'Vge';
$strEndCut = 'Kivgs Vge';
$strEndRaw = 'Feldolgozatlan Vge';
$strEngineAvailable = '%s elrhet&#337; ezen a MySQL szerveren.';
$strEngineDisabled = '%s le van tiltva ezen a MySQL szerveren.';
$strEnglish = 'Angol';  
$strEnglishPrivileges = ' Megjegyzs: A MySQL privilgium nevek az angolbl szrmaznak ';
$strError = 'Hiba';
$strEstonian = 'szt';  
$strExcelEdition = 'Excel szerkeszts';  
$strExcelOptions = 'Excel opcik';  
$strExecuteBookmarked = 'Elmentett eljrs futtatsa';  
$strExplain = 'SQL magyarzat';
$strExport = 'Export';
$strExtendedInserts = 'Kiterjesztett beszrsok';
$strExtra = 'Extra';

$strFailedAttempts = 'Hibs prblkozs'; 
$strField = 'Mez&#337;';
$strFieldHasBeenDropped = '%s mez&#337;t eldobtam';
$strFields = 'Mez&#337;k szma';
$strFieldsEmpty = ' A mez&#337; szmossga nulla! ';
$strFieldsEnclosedBy = 'Mez&#337; lezrs';
$strFieldsEscapedBy = 'Mez&#337; escape karakter';
$strFieldsTerminatedBy = 'Mez&#337; vge';
$strFileAlreadyExists = '%s fjl mr ltezik a szerveren, vltoztassa meg a fjlnevet, vagy lltsa be a fellrs opcit!';  
$strFileCouldNotBeRead = 'A fjl nem olvashat';  
$strFileNameTemplate = 'tmeneti fjlnv';
$strFileNameTemplateHelp = 'Hasznlja a __DB__ formult az adatbzis nevekhez, a __TABLE__ formult a tblanevekhez s %segy strftime%s formult az id&#337;-meghatrozshoz, a kiterjesztst automatikusan hozzadja. A tbbi szveget meg&#337;rzi.';
$strFileNameTemplateRemember = 'emlkezzen az tmeneti nvre';
$strFixed = 'rgztett';
$strFlushPrivilegesNote = 'Megjegyzs: a phpMyAdmin a felhasznli privilgiumokat kzvetlenl a MySQL privilgium tblkbl veszi. Ezen tblk tartalma eltrhet a szerver privilgiumoktl, ha ezt kzzel belltottuk. Ebben az esetben rdemes %sjra betlteni a privilgiumokat%s a folytats el&#337;tt.'; 
$strFlushTable = 'Tbla kirsa ("FLUSH")';
$strFormEmpty = 'Hinyz adat a form-ban !';
$strFormat = 'Formtum';
$strFullText = 'Teljes Szvegek';
$strFunction = 'Funkci';

$strGenBy = 'Ksztette';
$strGenTime = 'Ltrehozs ideje';
$strGeneralRelationFeat = 'ltalnos relcis jellemz&#337;k';
$strGeorgian = 'Grz';  
$strGerman = 'Nmet';  
$strGlobal = 'globlis';  
$strGlobalPrivileges = 'Globlis privilgiumok'; 
$strGlobalValue = 'Globlis vltoz'; 
$strGo = 'Vgrehajt';
$strGrantOption = 'Grant'; 
$strGreek = 'Grg';  
$strGzip = '"gzip-pel tmrtve"';

$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLExcelOptions = 'Microsoft Excel 2000 export belltsok';
$strHTMLWord = 'Microsoft Word 2000';
$strHTMLWordOptions = 'Microsoft Word 2000 export belltsok';
$strHasBeenAltered = 'megvltozott.';
$strHasBeenCreated = 'megszletett.';
$strHaveToShow = 'Legalbb egy oszlopot vlasztanod kell a megjelentshez';
$strHebrew = 'Hber';  
$strHexForBinary = 'Binris mez&#337;k hexadecimlisknt';
$strHome = 'Kezd&#337;lap';
$strHomepageOfficial = 'Hivatalos phpMyAdmin Honlap';
$strHost = 'Hoszt';
$strHostEmpty = 'A hosztnv res!';
$strHungarian = 'Magyar';  

$strIcelandic = 'Izlandi';
$strId = 'ID'; 
$strIdxFulltext = 'Fulltext';
$strIfYouWish = 'Ha csak a tbla nhny oszlopt akarod megjelenteni, adj meg egy vessz&#337;kkel elvlasztott mez&#337;listt.';
$strIgnore = 'Elutast';
$strIgnoreInserts = 'Mell&#337;z&#337; beszrsok hasznlata';  
$strIgnoringFile = '%s fjl mell&#337;zse';  
$strImportDocSQL = 'DocSQL fjlok importja';  
$strImportFiles = 'Fjlok importja';  
$strImportFinished = 'Import vget rt';  
$strInUse = 'hasznlatban';
$strIndex = 'Index';
$strIndexHasBeenDropped = '%s indexet eldobtam';
$strIndexName = 'Index nv:';
$strIndexType = 'Index tpus:';
$strIndexWarningTable = 'Problma a(z) `%s` tbla indexeivel';
$strIndexes = 'Indexek';
$strInnoDBDataFilePath = 'Adat fjlok';
$strInnodbStat = 'InnoDB llapot';  
$strInsecureMySQL = 'A konfigurcis fjl belltsa (root hozzfrs jelsz nlkl) az alaprtelmezett MySQL bellts. A MySQL szerver most ezzel fut, ami alkalmat ad a betrsre. Srg&#337;sen javtani kell ezt a biztonsgi rst.';  
$strInsert = 'Beszr';
$strInsertAsNewRow = 'Beszrs j sorknt';
$strInsertNewRow = 'j sor beszrsa';
$strInsertTextfiles = 'Szvegfjl tartalmnak beszrsa a tblba';
$strInsertedRowId = 'A beszrt rekord id-je:';  
$strInsertedRows = 'Beszrt sorok:';
$strInstructions = 'Parancs';
$strInternalNotNecessary = '* Egy bels&#337; kapcsolat nem szksges, ha az ltezik az InnoDB-ben is.';  
$strInternalRelations = 'Bels&#337; kapcsolatok';  

$strJapanese = 'Japn';  
$strJumpToDB = 'Ugrs a &quot;%s&quot; adatbzishoz.';  
$strJustDelete = 'Egyszer&#369;en trlje a felhasznlt a privilgium-tblkbl.'; 
$strJustDeleteDescr = 'A &quot;trlt&quot; felhasznlk mg hozzfrhetnek a szerverhez, amg a privilgiumok jratltse nem trtnik meg.'; 

$strKeepPass = 'Ne vltoztasd meg a jelszt';
$strKeyname = 'Kulcsnv';
$strKill = 'Lellt';
$strKorean = 'Koreai';  

$strLaTeX = 'LaTeX';  
$strLaTeXOptions = 'LaTeX opcik';  
$strLandscape = 'Fekv&#337;';  
$strLatexCaption = 'Tblacm';
$strLatexContent = 'tbla tartalom __TABLE__';
$strLatexContinued = '(folytats)';
$strLatexContinuedCaption = 'Tbla cm folytatsa';
$strLatexIncludeCaption = 'Tbla cme tartalmazza';
$strLatexLabel = 'Felirat kulcs';
$strLatexStructure = 'Tblaszerkezet __TABLE__';
$strLatvian = 'Litvn';
$strLengthSet = 'Hossz/rtk*';
$strLimitNumRows = 'Sorok szma oldalanknt';
$strLineFeed = 'Soremels: \\n';
$strLinesTerminatedBy = 'Sorok vge';
$strLinkNotFound = 'Link nem tallhat';
$strLinksTo = 'Linkek:';
$strLithuanian = 'Litvn';  
$strLoadExplanation = 'A legjobb eljrs van alapbl belltva, de meg lehet vltoztatni, ha az sikertelen.';  
$strLoadMethod = 'LOAD eljrs';  
$strLocalhost = 'Helyi';
$strLocationTextfile = 'A szvegfjl helye';
$strLogPassword = 'Jelsz:';
$strLogServer = 'Szerver';  
$strLogUsername = 'Felhasznli nv:';
$strLogin = 'Belps';
$strLoginInformation = 'Belpsi informci'; 
$strLogout = 'Kilps';
$strLongOperation = 'A m&#369;velet sokig eltarthat. Mindenkpp folytatod?';

$strMIMETypesForTable = 'Tbla MIME-tpusok';  
$strMIME_MIMEtype = 'MIME-tpus';
$strMIME_available_mime = 'Elrhet&#337; MIME-tpusok';
$strMIME_available_transform = 'Elrhet&#337; talaktsok';
$strMIME_description = 'Lers';
$strMIME_nodescription = 'Ehhez az talaktshoz nem rhet&#337; el lers.<br />Krdezze a szerz&#337;t, aki ksztette: %s.';
$strMIME_transformation = 'Bngsz&#337; talakts';
$strMIME_transformation_note = 'Az elrhet&#337; talaktsi belltsok listjhoz s a hozzjuk tartoz MIME-tpusokhoz kattintson ide: %stransformation descriptions%s';
$strMIME_transformation_options = 'talakts belltsok';
$strMIME_transformation_options_note = 'Az talakts belltsokhoz rja be az rtkeket a kovetkez&#337; formtumban: \'a\',\'b\',\'c\'...<br />Ha visszapert ("\") vagy idz&#337;jelet ("\'") akar beszrni, hasznljon visszapert (pldul: \'\\\\xyz\' or \'a\\\'b\').';
$strMIME_without = 'A d&#337;lttel rt MIME-tpusok nem vlasztjk el az talaktsi funkcikat';
$strMaximumSize = 'Legnagyobb mret: %s%s';  
$strModifications = 'A vltozsokat elmentettem';
$strModify = 'Vltozs';
$strModifyIndexTopic = 'Index vltozsa';
$strMoreStatusVars = 'Tbb llapotvltoz'; 
$strMoveTable = 'Tbla thelyezse ide (adatbzis<b>.</b>tbla):';
$strMoveTableOK = '%s tblt thelyeztem ide: %s.';
$strMoveTableSameNames = 'Nem tudom a tblt ugyanarra mozgatni!';  
$strMultilingual = 'soknyelv&#369;';  
$strMustSelectFile = 'Vlassza ki a fjlt, amit be akar illeszteni.';  
$strMyISAMDataPointerSize = 'Adat mutat mrete';
$strMyISAMRecoverOptions = 'Automatikus helyrelltsi md';
$strMySQLCharset = 'MySQL karakterkszlet';
$strMySQLConnectionCollation = 'MySQL kapcsolat egyeztets'; 
$strMySQLReloaded = 'MySQL jratltve.';
$strMySQLSaid = 'MySQL jelzi: ';
$strMySQLServerProcess = 'MySQL %pma_s1%, szerver: %pma_s2%, felhasznl: %pma_s3%';
$strMySQLShowProcess = 'Mutasd meg a folyamatokat';
$strMySQLShowStatus = 'Mutasd meg a MySQL futsi informcikat';
$strMySQLShowVars = 'Mutasd meg a MySQL rendszer vltozkat';

$strName = 'Nv';
$strNeedPrimaryKey = 'Els&#337;dleges kulcs definilsa szksges a tblhoz.';  
$strNext = 'Kvetkez&#337;';
$strNo = 'Nem';
$strNoDatabases = 'Nincs adatbzis';
$strNoDatabasesSelected = 'Nincs adatbzis kivlasztva.';  
$strNoDescription = 'nincs lers';
$strNoDropDatabases = '"DROP DATABASE" utasts le van tiltva.';
$strNoExplain = 'SQL magyarzat tugrsa';
$strNoFrames = 'A phpMyAdmin hasznlhatbb egy <b>frame-kezel&#337;</b> bngsz&#337;ben.';
$strNoIndex = 'Nincs index meghatrozva!';
$strNoIndexPartsDefined = 'Nincs index darab meghatrozva!';
$strNoModification = 'Nincs vltozs';
$strNoOptions = 'Ennek nincs belltsi lehet&#337;sge';
$strNoPassword = 'Nincs jelsz';
$strNoPermission = 'A webszervernek nincs joga elmenteni a fjlt: %s.';  
$strNoPhp = 'PHP kd nlkl';
$strNoPrivileges = 'Nincs privilgium';
$strNoQuery = 'Nincs SQL krs!';
$strNoRights = 'Nincs elg jogod ennek vgrehajtsra!';
$strNoRowsSelected = 'Nincs sor kivlasztva';  
$strNoSpace = 'Nincs elg hely elmenteni a fjlt: %s.';  
$strNoTablesFound = 'Nincs tbla az adatbzisban.';
$strNoThemeSupport = 'Nincs tma tmogats, ellen&#337;rizd a belltsokat s/vagy a tmkat a %s knyvtrban.';
$strNoUsersFound = 'Nem talltam felhasznl(ka)t.';
$strNoValidateSQL = 'SQL jvhagys tugrsa';
$strNone = 'Nincs';
$strNotNumber = 'Ez nem egy szm!';
$strNotOK = 'Nincs rendben';
$strNotSet = '<b>%s</b> tblt nem talltam vagy nincs benne: %s';
$strNull = 'Null';
$strNumSearchResultsInTable = '%s tallat <i>%s</i> tblban';
$strNumSearchResultsTotal = '<b>sszes:</b> <i>%s</i> tallat';
$strNumTables = 'Tbla'; 

$strOK = 'Rendben';
$strOftenQuotation = 'Gyakran idz&#337;jel. Opcionlisan a char s varchar mez&#337;k lezrhatk a \"lezrs\"-karakterrel.';
$strOperations = 'Tevkenysgek';
$strOperator = 'Kezel&#337;';  
$strOptimizeTable = 'Tbla optimalizls';
$strOptionalControls = 'Opcionlis. Vezrl&#337;k, amelyekkel rhatsz s olvashatsz specilis karaktereket.';
$strOptionally = 'Opcionlis';
$strOr = 'Vagy';
$strOverhead = 'Fellrs';
$strOverwriteExisting = 'Ltez&#337; fjlok fellrsa';  

$strPHP40203 = 'A PHP 4.2.3-as verzija fut, ami egy slyos hibt tartalmaz a tbb-bjtos sztringek kezelsnl (mbstring). Nzze meg a kvetkez&#337;t: PHP bug report 19404. A PHP ezen verzja nem ajnlott a phpMyAdminhoz.';  
$strPHPVersion = 'PHP Verzi';
$strPageNumber = 'Oldalszm:';
$strPagesToBeFlushed = 'Kirand oldalak';
$strPaperSize = 'Paprmret';  
$strPartialText = 'Rszleges Szvegek';
$strPassword = 'Jelsz';
$strPasswordChanged = '%s jelszavt sikeresen megvltoztattam.';
$strPasswordEmpty = 'A jelsz mez&#337; res!';
$strPasswordNotSame = 'A jelszavak nem azonosak!';
$strPdfDbSchema = '"%s" adatbzis smja - %s oldal';
$strPdfInvalidTblName = '"%s" tbla nem ltezik!';
$strPdfNoTables = 'Nincs tbla';
$strPerHour = 'rnknt'; 
$strPerMinute = 'percenknt';
$strPerSecond = 'msodpercenknt';
$strPersian = 'Perzsa';
$strPhoneBook = 'telefonknyv';  
$strPhp = 'PHP kd ksztse';
$strPmaDocumentation = 'phpMyAdmin dokumentci';
$strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> rtkt a konfigurcis fjlban KELL belltani!';
$strPolish = 'Lengyel';
$strPortrait = 'll';  
$strPos1 = 'Kezdet';
$strPrevious = 'El&#337;z&#337;';
$strPrimary = 'Els&#337;dleges';
$strPrimaryKeyHasBeenDropped = 'Az els&#337;dleges kulcsot eldobtam';
$strPrimaryKeyName = 'Az els&#337;dleges kulcs nevnek "PRIMARY"-nak kell lennie!';
$strPrimaryKeyWarning = '("PRIMARY"-nak <b>kell</b> lennie, s <b>csak annak</b> szabad lennie az els&#337;dleges kulcsnak!)';
$strPrint = 'Nyomtats';  
$strPrintView = 'Nyomtatsi nzet';
$strPrintViewFull = 'Nyomtatsi nzet (sszes szveggel)';  
$strPrivDescAllPrivileges = 'Minden privilgiumot tartalmaz, kivve a GRANT.'; 
$strPrivDescAlter = 'Engedlyezi a ltez&#337; tblk szerkezetnek megvltoztatst.'; 
$strPrivDescCreateDb = 'Engedlyezi j adatbzisok s tblk ksztst.'; 
$strPrivDescCreateTbl = 'Engedlyezi j tblk ksztst.'; 
$strPrivDescCreateTmpTable = 'Engedlyezi tmeneti tblk ksztst.'; 
$strPrivDescCreateView = 'j nzetek ltrehozsnak engedlyezse.';
$strPrivDescDelete = 'Engedlyezi az adatok trlst.'; 
$strPrivDescDropDb = 'Engedlyezi adatbzisok s tblk trlst.'; 
$strPrivDescDropTbl = 'Engedlyezi tblk trlst.'; 
$strPrivDescExecute = 'Engedlyezi trolt eljrsok futtatst; mg nem valsult meg ebben a MySQL verziban.'; 
$strPrivDescFile = 'Engedlyezi adatok export/importjt fjlokba.'; 
$strPrivDescGrant = 'Engedlyezi felhasznlk s privilgiumok hozzadst a privilgiumi tblk jratltse nlkl.'; 
$strPrivDescIndex = 'Engedlyezi indexek ksztst s trlst.'; 
$strPrivDescInsert = 'Engedlyezi adatok berst s megvltoztatst.'; 
$strPrivDescLockTables = 'Engedlyezi tblk blokkolst erre a szlra.'; 
$strPrivDescMaxConnections = 'Korltozza az j kapcsolatok szmt, amit a felhasznl rnknt megnyithat.';
$strPrivDescMaxQuestions = 'Korltozza a felhasznli lekrsek szmt rnknt.';
$strPrivDescMaxUpdates = 'Korltozza azon utastsok szmt rnknt, amelyek megvltoztatnak egy tblt vagy adatbzist.';
$strPrivDescProcess3 = 'Engedlyezi ms felhasznlk folyamatainak megszntetst.'; 
$strPrivDescProcess4 = 'Engedlyezi a teljes lekrsek megtekintst a folyamatlistban.'; 
$strPrivDescReferences = 'Nem valsult meg ebben a MySQL verziban'; 
$strPrivDescReload = 'Engedlyezi a szerver belltsok jratltst s a szerver-cache trlst.'; 
$strPrivDescReplClient = 'Jogokat ad a felhasznlnak, hogy lekrdezhessk a slave/master helyeket.'; 
$strPrivDescReplSlave = 'Szksges a slave-ek msolshoz.'; 
$strPrivDescSelect = 'Engedlyezi adatok olvasst.'; 
$strPrivDescShowDb = 'Hozzfrst ad az adatbzisok teljes listjhoz.'; 
$strPrivDescShutdown = 'Engedlyezi a szerver lelltst.'; 
$strPrivDescSuper = 'Engedlyezi a kapcsoldst akkor is, ha a kapcsolatok szma a maximumot elrte. Ez szksges a legfontosabb adminisztrcis m&#369;veletekhez, mint a globlis vltozk belltsa vagy ms felhasznlk folyamatainak megszntetse.'; 
$strPrivDescUpdate = 'Engedlyezi az adatok megvltoztatst.'; 
$strPrivDescUsage = 'Nincsenek privilgiumok.'; 
$strPrivileges = 'Privilgiumok';
$strPrivilegesReloaded = 'A privilgiumok jratltse sikeres volt.'; 
$strProcesslist = 'Folyamatlista'; 
$strPutColNames = 'Tegye a mez&#337;neveket az els&#337; sorhoz';  

$strQBE = 'Lekrdezs';
$strQBEDel = 'Trl';
$strQBEIns = 'Beszr';
$strQueryFrame = 'Lekrsi ablak';
$strQueryOnDb = 'SQL-krs <b>%s</b> adatbzison:';
$strQuerySQLHistory = 'SQL-el&#337;zmnyek';
$strQueryStatistics = '<b>Lekrsi statisztika</b>: Az induls ta %s krs ment el a szerverhez.';
$strQueryTime = 'A lekrs lefutott %01.4f msodperc alatt';
$strQueryType = 'Lekrs tpusa'; 
$strQueryWindowLock = 'Ne rja fell a lekrst az ablakon kvlr&#337;l';  

$strReType = 'jrars';
$strReadRequests = 'Olvassi krelmek';
$strReceived = 'Fogadott'; 
$strRecords = 'Sor';
$strReferentialIntegrity = 'Hivatkozsi srtetlensg ellen&#337;rzse:';
$strRefresh = 'Frissts';  
$strRelationNotWorking = 'A munka kiegszt&#337; tulajdonsgai a vonatkoz tblkra meg lettek szntetve. Az okokrt kattints %side%s.';
$strRelationView = 'Relci nzet';
$strRelationalSchema = 'Kapcsolati sma';  
$strRelations = 'Kapcsolatok';  
$strRelationsForTable = 'Tbla-kapcsolatok';  
$strReloadFailed = 'MySQL jratltse sikertelen.';
$strReloadMySQL = 'MySQL jratltse';
$strReloadingThePrivileges = 'Privilgiumok jratltse'; 
$strRemoveSelectedUsers = 'A kivlasztott felhasznlk trlse'; 
$strRenameDatabaseOK = '%s adatbzis tneveztem erre: %s';  
$strRenameTable = 'Tbla tnevezse erre';
$strRenameTableOK = '%s tblt tneveztem erre: %s';
$strRepairTable = 'Tbla javts';
$strReplace = 'Csere';
$strReplaceNULLBy = 'NULL cserje ezzel:';  
$strReplaceTable = 'Tbla adatok s fjl cserje';
$strReset = 'Trl';
$strResourceLimits = 'Er&#337;forrs hatrok'; 
$strRevoke = 'Visszavon';
$strRevokeAndDelete = 'A felhasznlk sszes privilgiumnak visszavonsa, aztn trlsk.'; 
$strRevokeAndDeleteDescr = 'A felhasznlknak mg hasznlhat privilgiumuk van, amg nem trtnik meg a privilgiumok jratltse.'; 
$strRevokeMessage = 'Visszavontam a %s privilgiumokat';
$strRomanian = 'Romn';
$strRowLength = 'Sorhossz';
$strRowSize = ' Sormret ';
$strRows = 'Sorok';
$strRowsFrom = 'sor kezdve ezzel:';
$strRowsModeFlippedHorizontal = 'vzszintes (elforgatott fejlc)';
$strRowsModeHorizontal = 'vzszintes';
$strRowsModeOptions = '%s mdon, a fejlcet %s soronknt megismtelve';
$strRowsModeVertical = 'fgg&#337;leges';
$strRowsStatistic = 'Sor-statisztika';
$strRunQuery = 'Krs vgrehajtsa';
$strRunSQLQuery = 'SQL parancs(ok) futtatsa a(z) %s adatbzison';
$strRunning = ': %s';
$strRussian = 'Orosz';  

$strSQL = 'SQL';
$strSQLExportCompatibility = 'SQL export kompatibilits';
$strSQLExportType = 'Export tpus';  
$strSQLOptions = 'SQL belltsok';
$strSQLParserBugMessage = 'Esly van r, hogy egy hibt tallhattl az SQL szintaktikai elemz&#337;ben (parser). Vizsgld meg gondosan a lekrdezsedet, ellen&#337;rizd, hogy az idz&#337;jelek jk s jl illeszkednek. Ms lehetsges hiba oka lehet, hogy binrisan tltttl fel egy fjlt az idzett szvegmez&#337;n kvl. Kiprblhatod a lekrsedet a MySQL parancssoros felletn.  A MySQL szerver hibakimenete alul lthat, ha van ott valami, az segthet felderteni a hiba okt. Ha mg mindig gondjaid vannak, vagy a szintaktiaki elemz&#337; (parser) hibt jelez, ahol a parancssoros felleten vgrehajtdik, redukld a problmt okoz SQL lekrdezst egy egyszer&#369; lekrdezss, s kldd el egy hibajelzsben (bug report) az als Kivgs rszben lev&#337; adatokkal egytt:';
$strSQLParserUserError = 'gy ltszik az SQL lekrdezsedben van egy hiba. A MySQL szerver hibakimenete alul lthat, ha van ott valami, az segthet felderteni a hiba okt';
$strSQLQuery = 'SQL-krs';
$strSQLResult = 'SQL eredmny';
$strSQPBugInvalidIdentifer = 'rvnytelen azonost';
$strSQPBugUnclosedQuote = 'Lezratlan lekrdezs';
$strSQPBugUnknownPunctuation = 'Ismeretlen kzpontozott sztring';
$strSave = 'Ment';
$strSaveOnServer = 'Ments a szerver %s knyvtrba';  
$strScaleFactorSmall = 'A mret elem tl kicsi, hogy megfelel&#337; legyen a smhoz egy oldalon';
$strSearch = 'Keress';
$strSearchFormTitle = 'Keress az adatbzisban';
$strSearchInTables = 'Tbl(k)ban:';
$strSearchNeedle = 'Szavak vagy rtkek a keresshez (helyettest&#337; karakter: "%"):';
$strSearchOption1 = 'legalbb egy sz';
$strSearchOption2 = 'sszes sz';
$strSearchOption3 = 'a helyes mondat';
$strSearchOption4 = 'regulris kifejezsknt';
$strSearchResultsFor = 'Keressi eredmnyek "<i>%s</i>" %s:';
$strSearchType = 'Keress:';
$strSecretRequired = 'A konfigurcis fjl egy titkos jelsz kifejezst vr (blowfish_secret).';  
$strSelectADb = 'Vlassz egy adatbzist';
$strSelectAll = 'Mindet kijelli';
$strSelectFields = 'Mez&#337;k kivlasztsa (legalbb egyet):';
$strSelectNumRows = 'krsben';
$strSelectTables = 'Tblk kivlasztsa';
$strSend = 'Fjlnv megadsa';
$strSent = 'Kldtt'; 
$strServer = 'Szerver';  
$strServerChoice = 'Szerver Vlaszts';
$strServerNotResponding = 'A szerver nem vlaszol';  
$strServerStatus = 'Futsi informcik'; 
$strServerStatusUptime = 'Ez a MySQL szerver fut: %s. Elindtva: %s.'; 
$strServerTabProcesslist = 'Folyamatok'; 
$strServerTabVariables = 'Vltozk'; 
$strServerTrafficNotes = '<b>Szerver forgalom</b>: Ezek a tblk mutatjk a MySQL szerver hlzati forgalom-statisztikit az indulstl kezdve.';
$strServerVars = 'Szerver vltozk s belltsok'; 
$strServerVersion = 'Szerver verzi';
$strSessionValue = 'Session rtk'; 
$strSetEnumVal = 'Ha a mez&#337; tpusa "enum" vagy "set", akkor az rtkeket ilyen formban rd be: \'a\',\'b\',\'c\'...<br />Ha backslash-t ("\") vagy aposztrfot ("\'") akarsz ezen rtkek kztt hasznlni, hasznld a backslash escape karaktert (pl.: \'\\\\xyz\' vagy \'a\\\'b\').';
$strShow = 'Mutat';
$strShowAll = 'Mutasd mindet';
$strShowColor = 'Mutasd a szneket';
$strShowDatadictAs = 'Adatknyvtr formtum';  
$strShowFullQueries = 'Teljes lekrsek mutatsa';  
$strShowGrid = 'Mutasd a rcsot';
$strShowPHPInfo = 'PHP informci';
$strShowTableDimension = 'Mutasd a tblk mrett';
$strShowTables = 'Mutasd a tblkat';
$strShowThisQuery = ' Mutasd a parancsot itt jra ';
$strShowingRecords = 'Sorok megjelentse ';
$strSimplifiedChinese = 'Egyszer&#369;stett knai';  
$strSingly = '(egyenknt)';
$strSize = 'Mret';
$strSlovak = 'Szlovk';
$strSlovenian = 'Szlovn';
$strSort = 'Sorrendezs';
$strSortByKey = 'Kulcs szerinti rendezs';  
$strSpaceUsage = 'Helyfoglals';
$strSpanish = 'Spanyol';  
$strSplitWordsWithSpace = 'A szavak fel vannak osztva szkz karakter szerint (" ").';
$strStatCheckTime = 'Utols ellen&#337;rzs';
$strStatCreateTime = 'Ltrehozs';
$strStatUpdateTime = 'Utols mdosts';
$strStatement = 'Adatok';
$strStatus = 'llapot'; 
$strStrucCSV = 'CSV adat';
$strStrucData = 'Szerkezet s adatok';
$strStrucDrop = '\'Tbla eldobs\' hozzadsa';
$strStrucExcelCSV = 'MS Excel CSV adat';
$strStrucNativeExcel = 'Natv MS Excel adat';  
$strStrucOnly = 'Csak szerkezet';
$strStructPropose = 'Tbla struktra ajnlat';
$strStructure = 'Struktra';
$strSubmit = 'Vgrehajt';
$strSuccess = 'Az SQL-krst sikeresen vgrehajtottam';
$strSum = 'sszesen';
$strSwedish = 'Svd';  
$strSwitchToDatabase = 'Vlts a msolt adatbzisra';
$strSwitchToTable = 'Vlts a msolt tblra';  

$strTable = 'Tbla';
$strTableComments = 'Tbla megjegyzsek';
$strTableEmpty = 'A tblanv helye res!';
$strTableHasBeenDropped = '%s tblt eldobtam';
$strTableHasBeenEmptied = '%s tblt kirtettem';
$strTableHasBeenFlushed = '%s tblt kirtam';
$strTableMaintenance = 'Tbla karbantarts';
$strTableOfContents = 'Tartalomjegyzk';  
$strTableOptions = 'Tbla opcik';  
$strTableStructure = 'Tbla szerkezet:';
$strTableType = 'Tbla tpusa';
$strTables = '%s tbla';
$strTakeIt = 'csinld';  
$strTblPrivileges = 'Tbla-specifikus privilgiumok'; 
$strTextAreaLength = ' Mivel ez a hossz,<br /> ez a mez&#337; nem szerkeszthet&#337; ';
$strThai = 'Thai';  
$strTheContent = 'A fjl tartalmt beillesztettem.';
$strTheContents = 'A fjl s a kivlasztott tbla sorainak tartalmt azonos els&#337;dleges vagy egyedi kulccsal cserli ki.';
$strTheTerminator = 'A mez&#337;k lezrja.';
$strTheme = 'Tma / Stlus';  
$strThisHost = 'Ez a gp'; 
$strThisNotDirectory = 'Ez nem alknyvtr volt';  
$strThreadSuccessfullyKilled = 'A %s. szlat sikerlt megszntetni.'; 
$strTime = 'Id&#337;'; 
$strToggleScratchboard = 'scratchboard kapcsolsa';  
$strTotal = 'sszesen';
$strTotalUC = 'ssz'; 
$strTraditionalChinese = 'Hagyomnyos knai';  
$strTraditionalSpanish = 'Hagyomnyos spanyol';
$strTraffic = 'Forgalom'; 
$strTransformation_application_octetstream__download = 'Egy linket jelent meg a mez&#337; binri adanak letltshez. Els&#337; opci a binris fjl neve. Msodik a tbla sornak egy lehetsges mez&#337;neve fjlnv gyannt. Ha belltja a msodik opcit, akkor az els&#337;t resen kell hagyni';  
$strTransformation_image_jpeg__inline = 'Kattinthat ikon mutatsa; belltsok: szlessg,magassg pixelben (megtartja az eredeti kparnyt)';  
$strTransformation_image_jpeg__link = 'Egy linket mutat a kphez (kzvetlen ablakos letlts).';
$strTransformation_image_png__inline = 'image/jpeg megtekintse: bent';  
$strTransformation_text_plain__dateformat = 'A TIME, TIMESTAMP vagy DATETIME mez&#337;k s formtumok az n helyi dtumformtumt hasznljk. Els&#337; opci az eltrs (rban), ami hozzaddik az id&#337;hz (alaprtelmezett: 0). A msodik egy klnbz&#337; id&#337;formtum a PHP strftime() paramtere szerint.';
$strTransformation_text_plain__external = 'Csak LINUX: Elindt egy kls&#337; programot, ami megkapja az adatokat a standard inputon. Visszatr a program standard outputjn. Alaprtelmezett a Tidy, csinos HTML kdot kap. Biztonsgi megfontolsokbl kzzel kell szerkeszteni a libraries/transformations/text_plain__external.inc.php fjlt, s berni a program nevt, amit futtatni akar. Az els&#337; opci a program szma, amit futtatni akar, a msodik a program paramterei. A harmadik opci ha egyenl&#337; eggyel, akkor a kimenet konvertlva lesz a htmlspecialchars() eljrssal (alaprtelmezett 1). A negyedik opci ha egyre van belltva, egy NOWRAP formzst ad minden mez&#337;hz, gy a kimenet jratrdels nlkl ltszik (alaprtelmezett 1)';
$strTransformation_text_plain__formatted = 'A mez&#337; eredeti formzsnak meg&#337;rzse. Nincs kivtel.';
$strTransformation_text_plain__imagelink = 'Egy kpet es egy linket jelent meg, a mez&#337; tartalmazza a fjlnevet; az els&#337; opc egy el&#337;tag, mint pl.: "http://domain.com/", a msodik a szlessg pixelben, a harmadik pedig a magassg.';  
$strTransformation_text_plain__link = 'Meg linket jelent meg, a megz&#337; tartalmazza a fjlnevet; az els&#337; opc egy el&#337;tag, mint pl.: "http://domain.com/", a msodik a link neve.';  
$strTransformation_text_plain__substr = 'A szveg egy rszt mutatja. Els&#337; opci egy offszet, ami a kezd&#337;pozcit lltja be (alaprtelmezett: 0). A msodik azt adja meg, hogy mennyi szveg jjjn vissza. Ha res, az sszes visszamarad szveg tjn. A harmadik opciban atokat a karaktereket lehet belltani, amik a szveg vgre kerlnek, ha szvegrszt kapunk vissza (alaprtelmezett: ...) .';
$strTruncateQueries = 'A mutatott krsek trlse';  
$strTurkish = 'Trk';  
$strType = 'Tpus';

$strUkrainian = 'Ukrn';  
$strUncheckAll = 'sszeset trli';
$strUnicode = 'Unicode';  
$strUnique = 'Egyedi';
$strUnknown = 'ismeretlen';  
$strUnselectAll = 'Mindet trli';
$strUpdComTab = 'Olvassa el a Dokumentcit, hogyan tudja mdostani a Column_comments tblt';  
$strUpdatePrivMessage = 'Frisstettem a(z) %s privilgiumokat.';
$strUpdateProfileMessage = 'A profilt frisstettem.';
$strUpdateQuery = 'Krs frisstse';
$strUpgrade = 'Mdosts szksges %s %s vagy ks&#337;bb.';  
$strUsage = 'Mret';
$strUseBackquotes = 'Idz&#337;jelek hasznlata a tbla- s mez&#337;neveknl';
$strUseHostTable = 'Hoszt-tbla hasznlata';  
$strUseTables = 'Tblk hasznlata';
$strUseTextField = 'Szveges mez&#337; hasznlata'; 
$strUseThisValue = 'Ezen rtk hasznlata';  
$strUser = 'Felhasznl';
$strUserAlreadyExists = '%s felhasznl mr ltezik!'; 
$strUserEmpty = 'A felhasznli nv mez&#337;je res!';
$strUserName = 'Felhasznli nv';
$strUserNotFound = 'A kivlasztott felhasznlt nem talltam a privilgium tblban.'; 
$strUserOverview = 'Felhasznl ttekints'; 
$strUsersDeleted = 'A kivlasztott felhasznlk trlse sikerlt.'; 
$strUsersHavingAccessToDb = 'A felhasznlknak hozzfrsk van ehhez: &quot;%s&quot;';  

$strValidateSQL = 'SQL jvhagys';
$strValidatorError = 'Az SQL ellen&#337;rz&#337;t (SQL validator) nem sikerlt elindtani. Ellen&#337;rizze a szksges php kiterjesztst, ahogy itt le van rva: %sdocumentation%.'; 
$strValue = 'rtk';
$strVar = 'Vltoz'; 
$strVersionInformation = 'Verzi informcik';
$strView = 'Nzet';
$strViewDump = 'Tbla kirs (vzlat) megnzse';
$strViewDumpDB = 'Adatbzis kirs (vzlat) megnzse';
$strViewDumpDatabases = 'Adatbzis kirs (sma) megtekintse';
$strViewHasBeenDropped = '%s nzet eldobva';

$strWebServerUploadDirectory = 'webszerver feltltsi knyvtr';  
$strWebServerUploadDirectoryError = 'Az alknyvtr, ami a feltltsekhez be lett lltva, nem elrhet&#337;';  
$strWelcome = 'dvzl a %s';
$strWestEuropean = 'Nyugat-eurpai';  
$strWildcard = 'helyettest&#337; jel';  
$strWindowNotFound = 'A cl bngsz&#337;ablakot nem tudtam jratlteni. Taln a szl&#337;ablak be lett zrva, vagy a bngsz&#337; biztonsgi belltsa tiltja az ablakok kzti jratltst';  
$strWithChecked = 'A kijelltekkel vgzend&#337; m&#369;velet:';
$strWriteRequests = 'rsi krelmek';
$strWritingCommentNotPossible = 'Megjegyzs rsa nem lehetsges';  
$strWritingRelationNotPossible = 'Kapcsolat rsa nem lehetsges';  
$strWrongUser = 'Hibs felhasznli nv/jelsz. Hozzfrs megtagadva.';

$strXML = 'XML';

$strYes = 'Igen';

$strZeroRemovesTheLimit = 'Megjegyzs: A 0 (nulla) belltsa trli a limitet.'; 
$strZip = '"zippel tmrtve"';

// To translate:

$strBinLogEventType = 'Event type';  //to translate
$strBinLogName = 'Log name';  //to translate
$strBinaryLog = 'Binary log';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strBusyPages = 'Busy pages';  //to translate

$strCopy = 'Copy';  //to translate
$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE msols el&#337;tt';  //to translate

$strDataPages = 'Pages containing data';  //to translate
$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
$strDirtyPages = 'Dirty pages';  //to translate

$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
$strEngines = 'Engines';  //to translate
$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate

$strFreePages = 'Free pages';  //to translate

$strGenerate = 'Generate';  //to translate
$strGeneratePassword = 'Generate Password';  //to translate

$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBDataHomeDir = 'Data home directory';  //to translate
$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
$strInnoDBPages = 'pages';  //to translate
$strInsertBookmarkTitle = 'Please insert bookmark title';  //to translate

$strLatchedPages = 'Latched pages';  //to translate

$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
$strMyISAMRepairThreads = 'Repair threads';  //to translate
$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate

$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate

$strPasswordHashing = 'Password Hashing';  //to translate
$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';  //to translate
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
$strPrivDescCreateUser = 'Allows creating, dropping and renaming unser accounts.';  //to translate
$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate

$strRoutines = 'Routines';  //to translate

$strSelectBinaryLog = 'Select binary log to view';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
$strStorageEngine = 'Storage Engine';  //to translate
$strStorageEngines = 'Storage Engines';  //to translate

$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate

$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate

$strInvalidFieldCount = 'Table must have at least one field.';  //to translate
$strInvalidRowNumber = '%d is not valid row number.';  //to translate
$strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
$strInvalidFieldAddCount = 'You have to add at least one field.';  //to translate
$strAndThen = 'and then';  //to translate
?>
